/*
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with thi1s program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "tablet_mode_switch_monitoring.h"
#include "libinput_switch_event.h"

#define SETTINGS_KYLINSTATUSMANAGER    "org.kylin-status-manager"
#define MODE_MONITER         "modemonitor" // 是否监听角度值


Tablet_Mode_Switch_Monitoring::Tablet_Mode_Switch_Monitoring(QObject *parent) : QObject(parent)
{
    QByteArray id(SETTINGS_KYLINSTATUSMANAGER);
    if(QGSettings::isSchemaInstalled(id))
    {
        status_manager_Setting = new QGSettings(id);
        modemonitor=status_manager_Setting->get(MODE_MONITER).toBool();
        connect(status_manager_Setting, &QGSettings::changed, [this](const QString & key) {
            qInfo()<<"org.kylin-status-manager"<<key;
            if (key == MODE_MONITER) {
                modemonitor=status_manager_Setting->get(MODE_MONITER).toBool();
            }
        });
    }else {
        qInfo()<<"org.kylin-status-manager is not install";
        return;
    }

    qDebug()<<"create libinput switch event";
    libswitch = new Libinput_Switch_Event;
    connect(libswitch , &Libinput_Switch_Event::tablet_mode_status_changed,this,[=](int tablet_mode){
        qDebug()<<"libinput switch event changed";
        qDebug()<<"modemonitor"<<modemonitor;
            qInfo()<<"tablet mode changed"<<"tablet mode is :"<<tablet_mode;
            if(tablet_mode == 1) {
                //平板
                if(modemonitor) {
                    Q_EMIT tablet_mode_change_signal(true);
                }
                Q_EMIT builtin_keyboard_change_signal(false);
            }else {
                //pc
                if(modemonitor) {
                    Q_EMIT tablet_mode_change_signal(false);
                }
                Q_EMIT builtin_keyboard_change_signal(true);
            }

    });
}
Tablet_Mode_Switch_Monitoring::~Tablet_Mode_Switch_Monitoring()
{
    if(libswitch){
        delete libswitch;
    }
    if(status_manager_Setting){
        delete status_manager_Setting;
    }
}
bool Tablet_Mode_Switch_Monitoring::get_tablet_mode_status()
{

    if(libswitch) {
        int status = libswitch->get_init_devices_status();
        qDebug()<<"libinput ================= status"<<status;
        if(status == 1){
            return true;
        }else if(status == 0){
            return false;
        }else {
            //返回值异常，不支持平板模式
            return false;
        }
    }else {
        return false;
    }
}
bool Tablet_Mode_Switch_Monitoring::get_builtin_keyboard_status()
{
    if(libswitch) {
        int status = libswitch->get_init_devices_status();
        if(status == 1){
            return false;
        }else if(status == 0){
            return true;
        }else {
            //返回值异常，不支持平板模式
            return true;
        }
    }else {
        return true;
    }

}
